@@ -153,30 +153,15 @@ class JsonContainerProperty(JsonProperty):
 class DefaultProperty(JsonProperty):
     def wrap(self, obj):
         from . import convert
-        from properties import DictProperty
-        from properties import ListProperty
-        if isinstance(obj, dict):
-            property_ = DictProperty()
-        elif isinstance(obj, list):
-            property_ = ListProperty()
-        else:
-            value = convert.value_to_python(obj)
-            property_ = convert.value_to_property(value)
+        value = convert.value_to_python(obj)
+        property_ = convert.value_to_property(value)
 
         if property_:
             return property_.wrap(obj)
 
     def unwrap(self, obj):
         from . import convert
-        from properties import DictProperty
-        from properties import ListProperty
-        if isinstance(obj, dict):
-            property_ = DictProperty()
-        elif isinstance(obj, list):
-            property_ = ListProperty()
-        else:
-            property_ = convert.value_to_property(obj)
-
+        property_ = convert.value_to_property(obj)
         if property_:
             return property_.unwrap(obj)
         else:
@@ -190,11 +175,16 @@ class AssertTypeProperty(JsonProperty):
         if not isinstance(obj, self._type):
             raise BadValueError('{0} not of type {1}'.format(obj, self._type))
 
+    def selective_coerce(self, obj):
+        return obj
+
     def wrap(self, obj):
+        obj = self.selective_coerce(obj)
         self.assert_type(obj)
         return obj
 
     def unwrap(self, obj):
+        obj = self.selective_coerce(obj)
         self.assert_type(obj)
         return obj, obj
 
